@@ -6,7 +6,7 @@
  *  UCRL-CODE-235197
  *
  *  This file is part of the SPL, Solaris Porting Layer.
- *  For details, see <http://github.com/behlendorf/spl/>.
+ *  For details, see <http://zfsonlinux.org/>.
  *
  *  The SPL is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -32,8 +32,6 @@
  * ensure 32-bit/64-bit interoperability over ioctl()'s only types with
  * fixed sizes can be used.
  */
-#define SPLAT_MAJOR			225 /* XXX - Arbitrary */
-#define SPLAT_MINORS                    1
 #define SPLAT_NAME			"splatctl"
 #define SPLAT_DEV			"/dev/splatctl"
 
@@ -104,6 +102,8 @@ typedef struct splat_cmd {
 #define SPLAT_SUBSYSTEM_LIST		0x0c00
 #define SPLAT_SUBSYSTEM_GENERIC		0x0d00
 #define SPLAT_SUBSYSTEM_CRED		0x0e00
+#define SPLAT_SUBSYSTEM_ZLIB		0x0f00
+#define SPLAT_SUBSYSTEM_LINUX		0x1000
 #define SPLAT_SUBSYSTEM_UNKNOWN		0xff00
 
 #endif /* _SPLAT_CTL_H */
