@@ -6,7 +6,7 @@
  *  UCRL-CODE-235197
  *
  *  This file is part of the SPL, Solaris Porting Layer.
- *  For details, see <http://github.com/behlendorf/spl/>.
+ *  For details, see <http://zfsonlinux.org/>.
  *
  *  The SPL is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -25,49 +25,10 @@
 #ifndef _SPLAT_INTERNAL_H
 #define _SPLAT_INTERNAL_H
 
-#include <linux/kernel.h>
-#include <linux/module.h>
-#include <linux/string.h>
-#include <linux/errno.h>
-#include <linux/slab.h>
-#include <linux/sched.h>
-#include <linux/elf.h>
-#include <linux/limits.h>
-#include <linux/version.h>
-#include <linux/vmalloc.h>
-#include <linux/module.h>
-#include <linux/device.h>
-#include <linux/list.h>
-#include <linux/swap.h>
-#include <linux/delay.h>
-
-#include <asm/ioctls.h>
-#include <asm/uaccess.h>
-#include <stdarg.h>
-
-#include <sys/callb.h>
-#include <sys/condvar.h>
-#include <sys/cred.h>
-#include <sys/sysmacros.h>
-#include <sys/kmem.h>
-#include <sys/kstat.h>
-#include <sys/mutex.h>
-#include <sys/random.h>
-#include <sys/rwlock.h>
-#include <sys/taskq.h>
-#include <sys/thread.h>
-#include <sys/time.h>
-#include <sys/timer.h>
-#include <sys/types.h>
-#include <sys/kobj.h>
-#include <sys/atomic.h>
-#include <sys/list.h>
-#include <sys/sunddi.h>
-#include <linux/cdev.h>
-
-#include "spl-device.h"
-#include "spl-debug.h"
 #include "splat-ctl.h"
+#include <sys/mutex.h>
+#include <linux/file_compat.h>
+#include <linux/version.h>
 
 #define SPLAT_SUBSYSTEM_INIT(type)                                      \
 ({      splat_subsystem_t *_sub_;                                       \
@@ -161,7 +122,7 @@ typedef struct splat_subsystem {
 #define SPLAT_INFO_BUFFER_REDZONE	256
 
 typedef struct splat_info {
-	spinlock_t info_lock;
+	kmutex_t info_lock;
 	int info_size;
 	char *info_buffer;
 	char *info_head;	/* Internal kernel use only */
@@ -176,7 +137,7 @@ typedef struct splat_info {
 	ASSERT(_info_);							\
 	ASSERT(_info_->info_buffer);					\
 									\
-	spin_lock(&_info_->info_lock);					\
+	mutex_enter(&_info_->info_lock);				\
 									\
 	/* Don't allow the kernel to start a write in the red zone */	\
 	if ((int)(_info_->info_head - _info_->info_buffer) >		\
@@ -188,7 +149,7 @@ typedef struct splat_info {
 			_info_->info_head += _rc_;			\
 	}								\
 									\
-	spin_unlock(&_info_->info_lock);				\
+	mutex_exit(&_info_->info_lock);					\
 	_rc_;								\
 })
 
@@ -218,6 +179,8 @@ splat_subsystem_t *splat_atomic_init(void);
 splat_subsystem_t *splat_list_init(void);
 splat_subsystem_t *splat_generic_init(void);
 splat_subsystem_t *splat_cred_init(void);
+splat_subsystem_t *splat_zlib_init(void);
+splat_subsystem_t *splat_linux_init(void);
 
 void splat_condvar_fini(splat_subsystem_t *);
 void splat_kmem_fini(splat_subsystem_t *);
@@ -233,6 +196,8 @@ void splat_atomic_fini(splat_subsystem_t *);
 void splat_list_fini(splat_subsystem_t *);
 void splat_generic_fini(splat_subsystem_t *);
 void splat_cred_fini(splat_subsystem_t *);
+void splat_zlib_fini(splat_subsystem_t *);
+void splat_linux_fini(splat_subsystem_t *);
 
 int splat_condvar_id(void);
 int splat_kmem_id(void);
@@ -248,5 +213,7 @@ int splat_atomic_id(void);
 int splat_list_id(void);
 int splat_generic_id(void);
 int splat_cred_id(void);
+int splat_zlib_id(void);
+int splat_linux_id(void);
 
 #endif /* _SPLAT_INTERNAL_H */
